import { useState, useEffect, lazy, Suspense } from "react";
import Header from "@/components/Header";
import Footer from "@/components/Footer";
import { Tabs, TabsContent, TabsList, TabsTrigger } from "@/components/ui/tabs";
import { useIsMobile } from "@/hooks/use-mobile";
import { useDeferHeavyComponents, useMobileOptimization } from "@/hooks/use-defer-heavy-components";
import { Select, SelectContent, SelectItem, SelectTrigger, SelectValue } from "@/components/ui/select";
import NonBlockingRenderer from "@/components/NonBlockingRenderer";

// Lazy load heavy calculator components with higher priority
const MortgageCalculator = lazy(() => 
  import("@/components/calculators/MortgageCalculator").then(module => ({
    default: module.default
  }))
);
const RetirementCalculator = lazy(() => 
  import("@/components/calculators/RetirementCalculator").then(module => ({
    default: module.default
  }))
);
const EmergencyFundCalculator = lazy(() => 
  import("@/components/calculators/EmergencyFundCalculator").then(module => ({
    default: module.default
  }))
);

// Loading skeleton component
const CalculatorSkeleton = () => (
  <div className="animate-pulse">
    <div className="grid grid-cols-1 lg:grid-cols-2 gap-6">
      <div className="h-96 bg-gray-200 rounded-lg"></div>
      <div className="h-96 bg-gray-200 rounded-lg"></div>
    </div>
  </div>
);

export default function Home() {
  const [activeTab, setActiveTab] = useState("mortgage");
  const isMobile = useIsMobile();
  const { shouldLoadHeavy, isIdle } = useDeferHeavyComponents();
  const { isLowEnd } = useMobileOptimization();

  return (
    <div className="min-h-screen flex flex-col bg-gray-50">
      <Header />
      
      {/* Hero Section */}
      <section className="relative overflow-hidden bg-gradient-to-r from-gray-900 to-black py-10">
        <div className="absolute inset-0 opacity-10">
          <div className="absolute inset-0 bg-[radial-gradient(#ffffff33_1px,transparent_1px)]" style={{ backgroundSize: '20px 20px' }}></div>
        </div>
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 relative z-10">
          <div className="flex flex-col md:flex-row items-center justify-between">
            <div className="md:w-1/2 mb-8 md:mb-0 md:pr-12">
              <h2 className="text-3xl md:text-4xl font-bold text-white leading-tight">
                <span className="text-blue-400">Smart</span> Financial <br />
                <span className="text-blue-400">Calculators</span> for Everyone
              </h2>
              <p className="mt-4 text-lg text-gray-300 font-medium">
                Make informed decisions about your financial future with our easy-to-use tools.
              </p>
              <div className="mt-6 flex space-x-3">
                <div className="flex items-center text-gray-300">
                  <svg className="h-5 w-5 text-blue-400 mr-2" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                    <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M5 13l4 4L19 7" />
                  </svg>
                  <span>Simple</span>
                </div>
                <div className="flex items-center text-gray-300">
                  <svg className="h-5 w-5 text-blue-400 mr-2" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                    <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M5 13l4 4L19 7" />
                  </svg>
                  <span>Accurate</span>
                </div>
                <div className="flex items-center text-gray-300">
                  <svg className="h-5 w-5 text-blue-400 mr-2" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                    <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M5 13l4 4L19 7" />
                  </svg>
                  <span>Free</span>
                </div>
              </div>
            </div>
            <div className="md:w-1/2 flex justify-center">
              <div className="bg-gray-800 bg-opacity-50 backdrop-filter backdrop-blur-sm p-5 rounded-lg border border-gray-700 shadow-xl w-full max-w-md">
                <div className="grid grid-cols-3 gap-3 mb-2">
                  {["Mortgage", "Retirement", "Emergency"].map((tool, index) => (
                    <div key={index} className="bg-blue-600 bg-opacity-20 rounded p-2 text-center">
                      <div className="text-blue-400 font-medium text-sm">{tool}</div>
                      <div className="text-white text-xs mt-1">Calculator</div>
                    </div>
                  ))}
                </div>
                <p className="text-sm text-gray-400 text-center mt-2">
                  Plan your financial future with confidence using our specialized tools
                </p>
              </div>
            </div>
          </div>
        </div>
      </section>
      
      {/* Tools Section */}
      <section className="max-w-7xl mx-auto px-0 sm:px-6 lg:px-8 py-8 flex-grow">
        <div className="mb-6 px-1 sm:px-0">
          {isMobile ? (
            <Select value={activeTab} onValueChange={setActiveTab}>
              <SelectTrigger className="w-full text-base">
                <SelectValue placeholder="Select calculator" />
              </SelectTrigger>
              <SelectContent>
                <SelectItem value="mortgage">Mortgage Calculator</SelectItem>
                <SelectItem value="retirement">Retirement Savings</SelectItem>
                <SelectItem value="emergency">Emergency Fund</SelectItem>
              </SelectContent>
            </Select>
          ) : (
            <Tabs defaultValue="mortgage" value={activeTab} onValueChange={setActiveTab} className="w-full">
              <TabsList className="border-b border-gray-200 w-full grid grid-cols-3 p-0 bg-transparent">
                <TabsTrigger 
                  value="mortgage" 
                  className="data-[state=active]:border-primary-600 data-[state=active]:text-primary-600 data-[state=active]:shadow-none data-[state=active]:bg-white py-3 px-6 text-lg font-medium border-b-2 border-transparent data-[state=inactive]:text-gray-500 data-[state=inactive]:hover:text-gray-700 data-[state=inactive]:hover:border-gray-300 rounded-none"
                >
                  Mortgage Calculator
                </TabsTrigger>
                <TabsTrigger 
                  value="retirement" 
                  className="data-[state=active]:border-primary-600 data-[state=active]:text-primary-600 data-[state=active]:shadow-none data-[state=active]:bg-white py-3 px-6 text-lg font-medium border-b-2 border-transparent data-[state=inactive]:text-gray-500 data-[state=inactive]:hover:text-gray-700 data-[state=inactive]:hover:border-gray-300 rounded-none"
                >
                  Retirement Savings
                </TabsTrigger>
                <TabsTrigger 
                  value="emergency" 
                  className="data-[state=active]:border-primary-600 data-[state=active]:text-primary-600 data-[state=active]:shadow-none data-[state=active]:bg-white py-3 px-6 text-lg font-medium border-b-2 border-transparent data-[state=inactive]:text-gray-500 data-[state=inactive]:hover:text-gray-700 data-[state=inactive]:hover:border-gray-300 rounded-none"
                >
                  Emergency Fund
                </TabsTrigger>
              </TabsList>
            </Tabs>
          )}
        </div>

        <div className="calculator-container">
          {/* Only render calculators after idle time to prevent render blocking */}
          {shouldLoadHeavy ? (
            <NonBlockingRenderer delay={30} fallback={<CalculatorSkeleton />}>
              {activeTab === "mortgage" && (
                <Suspense fallback={<CalculatorSkeleton />}>
                  <MortgageCalculator />
                </Suspense>
              )}
              {activeTab === "retirement" && (
                <Suspense fallback={<CalculatorSkeleton />}>
                  <RetirementCalculator />
                </Suspense>
              )}
              {activeTab === "emergency" && (
                <Suspense fallback={<CalculatorSkeleton />}>
                  <EmergencyFundCalculator />
                </Suspense>
              )}
            </NonBlockingRenderer>
          ) : (
            <div className="bg-white rounded-lg shadow-lg p-8 text-center">
              <div className="inline-block animate-spin rounded-full h-8 w-8 border-b-2 border-blue-600 mb-4"></div>
              <h3 className="text-xl font-semibold text-gray-900 mb-2">
                Preparing {activeTab === "mortgage" ? "Mortgage" : activeTab === "retirement" ? "Retirement" : "Emergency Fund"} Calculator
              </h3>
              <p className="text-gray-600">Loading advanced financial tools...</p>
              <div className="mt-4 bg-gray-100 rounded-lg p-4">
                <div className="text-sm text-gray-700 mb-2">Quick Preview:</div>
                <div className="text-left space-y-1 text-sm text-gray-600">
                  {activeTab === "mortgage" && (
                    <>
                      <div>• Calculate monthly payments</div>
                      <div>• Compare loan terms</div>
                      <div>• Analyze total interest costs</div>
                    </>
                  )}
                  {activeTab === "retirement" && (
                    <>
                      <div>• Project retirement savings</div>
                      <div>• Plan monthly contributions</div>
                      <div>• Visualize growth over time</div>
                    </>
                  )}
                  {activeTab === "emergency" && (
                    <>
                      <div>• Calculate recommended fund size</div>
                      <div>• Plan saving timeline</div>
                      <div>• Track progress goals</div>
                    </>
                  )}
                </div>
              </div>
            </div>
          )}
        </div>
      </section>

      <Footer />
    </div>
  );
}
